---
title: "Urubu 1.0.0 released"
layout: page 
date: 2016-01-01
---

This release adds support for the `process_info` Python hook.  This hook
provides a powerful way to assist in templating. Basically, it provides full
Python power to inspect, verify, modify, and add page attributes. For example,
you can use it to define a default `layout`, or a specific `layout` 
for pages in a certain directory.

Read more in the manual: [/manual/hooks#The process_info hook].

There is also a new `keep_files` configuration attribute, that lets you
preserve files that would otherwise be ignored.  See the
[documentation][/manual/structure#_siteyml].
